@@ -13,13 +13,27 @@ import pytest
         ("oracle://user:pass@host:4444", "not supported", UnsupportedBackend),
         ("postgresql+psycopg3://user:pass@host:4444", "not supported", UnsupportedBackend),
         ("postgresql://user:pass@host:4444", "name is required but missing", ConfigurationError),
-        ("postgresql://user:pass@host:4444/dbname?pool_max_conn=ABC", "must be integer", ConfigurationError),
-        ("postgresql://user:pass@host:4444/dbname?pool_min_conn=ABC", "must be integer", ConfigurationError),
+        ("postgresql://user:pass@host:4444/dbname?pool_max_conn=ABC", "must be int", ConfigurationError),
+        ("postgresql://user:pass@host:4444/dbname?pool_min_conn=ABC", "must be int", ConfigurationError),
+        ("postgresql://user:pass@host:4444/dbname?weird=XYZ&defer=False", "Unexpected argument", ConfigurationError),
+        ("postgresql://user:pass@host:4444/dbname?defer=JUNK", "must be bool", ConfigurationError),
+        (
+            "postgresql://user:pass@host:4444/dbname?weird=JUNK&pool_threaded=True",
+            "Unexpected argument",
+            ConfigurationError,
+        ),
+        (
+            "postgresql://user:pass@host:4444/dbname?pool_min_conn=2&pool_max_conn=1",
+            "pool_max_conn must be greater or equal to pool_min_conn",
+            ConfigurationError,
+        ),
         (
             "postgresql://user:pass@host:4444/dbname?pool_min_conn=1&pool_min_conn=2",
             "single value",
             ConfigurationError,
         ),
+        ("sqlite3+invalid://test.db", "not supported", UnsupportedBackend),
+        ("sqlite3://test.db?schema=test", "Unexpected argument", ConfigurationError),
     ],
 )
 def test_backend_create_rejection(db_uri: str, match: str, except_class):
